==> customjson-1.9.2.tar.gz: customjson-1.9.2/customjson/defaults.py <==
"""Default values."""
REUSE = 'https://raw.githubusercontent.com/{}/{}/master/{}'
SKIP_REPOS = ['information', 'sensor.untapped', 'sun']
VISIT = 'https://github.com/{}/{}'

COMMIT = ["a few bits tried to escape, but we caught them",
          "add dirty scripts from the dark side of the universe",
          "And a commit that I don't know the reason of...",
          "arrgghh... damn this thing for not working.",
          "Best commit ever",
          "By works, I meant 'doesnt work'. Works now..",
          "Committing in accordance with the prophecy.",
          "Copy pasta fail. still had a instead of a",
          "Crap. Tonight is raid night and I am already late.",
          "Easteregg",
          "Either Hot Shit or Total Bollocks",
          "Fixed so the code compiles",
          "forgot we're not using a smart language",
          "hoo boy",
          "I know what I am doing. Trust me.",
          "I'm too foo for this bar",
          "making this thing actually usable.",
          "Merging 'WIP: Do Not Merge This Branch' Into Master",
          "Nothing to see here, move along",
          "Now added delete for real",
          "oops - thought I got that one.",
          "Push poorly written test can down the road another ten years",
          "QuickFix.",
          "Refactored configuration.",
          "Reset error count between rows. herpderp",
          'Revert "fuckup".',
          "restored deleted entities just to be sure",
          "So my boss wanted this button ...",
          "Test commit. Please ignore",
          "This is my code. My code is amazing."
          "This is why the cat shouldn't sit on my keyboard.",
          "workaround for ant being a pile of fail"]

"""
Commit msg's from https://whatthecommit.com/
"""

==> customjson-2.5.0.tar.gz: customjson-2.5.0/customjson/defaults.py <==
"""Default values."""
REUSE = 'https://raw.githubusercontent.com/{}/{}/master/{}'
BLACKLIST = ['information', 'sun']
DOMAINS = ['air_quality',
           'binary_sensor',
           'camera',
           'climate',
           'cover',
           'device_tracker',
           'fan',
           'image_processing',
           'light',
           'lock',
           'media_player',
           'notify',
           'remote',
           'sensor',
           'switch',
           'vaccum',
           'water_heater',
           'weather']
VISIT = 'https://github.com/{}/{}'

COMMIT = ["a few bits tried to escape, but we caught them",
          "add dirty scripts from the dark side of the universe",
          "And a commit that I don't know the reason of...",
          "arrgghh... damn this thing for not working.",
          "Best commit ever",
          "By works, I meant 'doesnt work'. Works now..",
          "Committing in accordance with the prophecy.",
          "Copy pasta fail. still had a instead of a",
          "Crap. Tonight is raid night and I am already late.",
          "Easteregg",
          "Either Hot Shit or Total Bollocks",
          "Fixed so the code compiles",
          "forgot we're not using a smart language",
          "hoo boy",
          "I know what I am doing. Trust me.",
          "I'm too foo for this bar",
          "making this thing actually usable.",
          "Merging 'WIP: Do Not Merge This Branch' Into Master",
          "Nothing to see here, move along",
          "Now added delete for real",
          "oops - thought I got that one.",
          "Push poorly written test can down the road another ten years",
          "QuickFix.",
          "Refactored configuration.",
          "Reset error count between rows. herpderp",
          'Revert "fuckup".',
          "restored deleted entities just to be sure",
          "So my boss wanted this button ...",
          "Test commit. Please ignore",
          "This is my code. My code is amazing."
          "This is why the cat shouldn't sit on my keyboard.",
          "workaround for ant being a pile of fail"]

"""
Commit msg's from https://whatthecommit.com/
"""
